# Simple Service Registration

This agent registers and unregisters its service on the SOEF.

## Description

This agent is used in the "Guide on Writing a Skill" section of the documentation. On start, it registers its service on the `SOEF`, and on termination it unregisters it.

## Links

* <a href="https://docs.fetch.ai/aea/skill-guide/" target="_blank">Guide on Building a Skill</a>
